nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Pio

Struct Pio 

#[repr(transparent)]
pub struct Pio(pub u32);
Digital I/O control for port 0 pins PIO0_13

Tuple Fields

0: u32

Implementations

Source

impl Pio

pub const fn func(&self) -> PioFunc

Selects pin function.

pub const fn set_func(&mut self, val: PioFunc)

Selects pin function.

pub const fn mode(&self) -> PioMode

Selects function mode (on-chip pull-up/pull-down resistor control).

pub const fn set_mode(&mut self, val: PioMode)

Selects function mode (on-chip pull-up/pull-down resistor control).

pub const fn slew(&self) -> PioSlew

Driver slew rate.

pub const fn set_slew(&mut self, val: PioSlew)

Driver slew rate.

pub const fn invert(&self) -> bool

Input polarity.

pub const fn set_invert(&mut self, val: bool)

Input polarity.

pub const fn digimode(&self) -> PioDigimode

Select Digital mode.

pub const fn set_digimode(&mut self, val: PioDigimode)

Select Digital mode.

pub const fn od(&self) -> PioOd

Controls open-drain mode in standard GPIO mode (EGP = 1). This bit has no effect in I2C mode (EGP=0).

pub const fn set_od(&mut self, val: PioOd)

Controls open-drain mode in standard GPIO mode (EGP = 1). This bit has no effect in I2C mode (EGP=0).

pub const fn asw(&self) -> PioAsw

Analog switch input control.

pub const fn set_asw(&mut self, val: PioAsw)

Analog switch input control.

pub const fn ssel(&self) -> PioSsel

Supply Selection bit.

pub const fn set_ssel(&mut self, val: PioSsel)

Supply Selection bit.

pub const fn filteroff(&self) -> PioFilteroff

Controls input glitch filter.

pub const fn set_filteroff(&mut self, val: PioFilteroff)

Controls input glitch filter.

pub const fn ecs(&self) -> bool

Pull-up current source enable in I2C mode.

pub const fn set_ecs(&mut self, val: bool)

Pull-up current source enable in I2C mode.

pub const fn egp(&self) -> PioEgp

Switch between GPIO mode and I2C mode.

pub const fn set_egp(&mut self, val: PioEgp)

Switch between GPIO mode and I2C mode.

pub const fn i2cfilter(&self) -> PioI2cfilter

Configures I2C features for standard mode, fast mode, and Fast Mode Plus operation and High-Speed mode operation.

pub const fn set_i2cfilter(&mut self, val: PioI2cfilter)

Configures I2C features for standard mode, fast mode, and Fast Mode Plus operation and High-Speed mode operation.